/// <reference types="react" />
import { ItemHeight, RenderItemArgs, SearchItemRequirements, SearchProps } from './Search';
type RecentSearchProps<T> = {
    /**
     * List of recently selected items.
     */
    recents: T[];
    /**
     * Height of each item in the list.
     */
    itemHeight: ItemHeight;
    /**
     * Whether the display is small (e.g. mobile).
     */
    smallDisplay: boolean;
    /**
     * Function to add an item to the list of recents.
     */
    getAddToRecentsFunc: (item: T) => RenderItemArgs<T>['addToRecents'];
    /**
     * Function to call when an item is selected.
     */
    onItemSelect: SearchProps<T>['onItemSelect'];
    /**
     * Optional render function for recent selections.
     */
    renderRecent?: SearchProps<T>['renderResult'];
    /**
     * Function to close the search dialog.
     */
    closeDialog: () => void;
    /**
     * Optional toolbar elements to display above the list of recents.
     */
    toolbarElements?: React.ReactNode;
};
/**
 * Returns list of recent searches with a header and optional toolbar elements.
 */
export declare const RecentSearches: <T extends SearchItemRequirements>(props: RecentSearchProps<T>) => JSX.Element;
export {};
